@@ -28,14 +28,14 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_iam
-import aws_cdk.aws_kinesis
-import aws_cdk.aws_lambda
-import aws_cdk.aws_logs
-import aws_cdk.core
+import aws_cdk.aws_iam as _aws_cdk_aws_iam_940a1ce0
+import aws_cdk.aws_kinesis as _aws_cdk_aws_kinesis_0674c215
+import aws_cdk.aws_lambda as _aws_cdk_aws_lambda_5443dbc3
+import aws_cdk.aws_logs as _aws_cdk_aws_logs_6c4320fb
+import aws_cdk.core as _aws_cdk_core_f4b25747
 
 
-@jsii.implements(aws_cdk.aws_logs.ILogSubscriptionDestination)
+@jsii.implements(_aws_cdk_aws_logs_6c4320fb.ILogSubscriptionDestination)
 class KinesisDestination(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-logs-destinations.KinesisDestination",
@@ -62,22 +62,16 @@ class KinesisDestination(
 
     def __init__(
         self,
-        stream: aws_cdk.aws_kinesis.IStream,
+        stream: _aws_cdk_aws_kinesis_0674c215.IStream,
         *,
-        role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+        role: typing.Optional[_aws_cdk_aws_iam_940a1ce0.IRole] = None,
     ) -> None:
         '''
         :param stream: The Kinesis stream to use as destination.
         :param role: The role to assume to write log events to the destination. Default: - A new Role is created
         '''
         if __debug__:
-            def stub(
-                stream: aws_cdk.aws_kinesis.IStream,
-                *,
-                role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__4c1fc1e74b65f4712e89c4da0bc617dea03f0d103b6d5ca34d70a034ee992f15)
             check_type(argname="argument stream", value=stream, expected_type=type_hints["stream"])
         props = KinesisDestinationProps(role=role)
 
@@ -86,9 +80,9 @@ class KinesisDestination(
     @jsii.member(jsii_name="bind")
     def bind(
         self,
-        scope: aws_cdk.core.Construct,
-        _source_log_group: aws_cdk.aws_logs.ILogGroup,
-    ) -> aws_cdk.aws_logs.LogSubscriptionDestinationConfig:
+        scope: _aws_cdk_core_f4b25747.Construct,
+        _source_log_group: _aws_cdk_aws_logs_6c4320fb.ILogGroup,
+    ) -> _aws_cdk_aws_logs_6c4320fb.LogSubscriptionDestinationConfig:
         '''Return the properties required to send subscription events to this destination.
 
         If necessary, the destination can use the properties of the SubscriptionFilter
@@ -102,15 +96,10 @@ class KinesisDestination(
         :param _source_log_group: -
         '''
         if __debug__:
-            def stub(
-                scope: aws_cdk.core.Construct,
-                _source_log_group: aws_cdk.aws_logs.ILogGroup,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__c036c7cb7cf460a876c094390792817933a81fdf009c1e122eac612b990bc23d)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument _source_log_group", value=_source_log_group, expected_type=type_hints["_source_log_group"])
-        return typing.cast(aws_cdk.aws_logs.LogSubscriptionDestinationConfig, jsii.invoke(self, "bind", [scope, _source_log_group]))
+        return typing.cast(_aws_cdk_aws_logs_6c4320fb.LogSubscriptionDestinationConfig, jsii.invoke(self, "bind", [scope, _source_log_group]))
 
 
 @jsii.data_type(
@@ -119,7 +108,11 @@ class KinesisDestination(
     name_mapping={"role": "role"},
 )
 class KinesisDestinationProps:
-    def __init__(self, *, role: typing.Optional[aws_cdk.aws_iam.IRole] = None) -> None:
+    def __init__(
+        self,
+        *,
+        role: typing.Optional[_aws_cdk_aws_iam_940a1ce0.IRole] = None,
+    ) -> None:
         '''Customize the Kinesis Logs Destination.
 
         :param role: The role to assume to write log events to the destination. Default: - A new Role is created
@@ -140,22 +133,20 @@ class KinesisDestinationProps:
             )
         '''
         if __debug__:
-            def stub(*, role: typing.Optional[aws_cdk.aws_iam.IRole] = None) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__70edd2e2361dad9ce17031d23675b0d1700425bd13f9b6b2318cf360863cc596)
             check_type(argname="argument role", value=role, expected_type=type_hints["role"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if role is not None:
             self._values["role"] = role
 
     @builtins.property
-    def role(self) -> typing.Optional[aws_cdk.aws_iam.IRole]:
+    def role(self) -> typing.Optional[_aws_cdk_aws_iam_940a1ce0.IRole]:
         '''The role to assume to write log events to the destination.
 
         :default: - A new Role is created
         '''
         result = self._values.get("role")
-        return typing.cast(typing.Optional[aws_cdk.aws_iam.IRole], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_iam_940a1ce0.IRole], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -169,7 +160,7 @@ class KinesisDestinationProps:
         )
 
 
-@jsii.implements(aws_cdk.aws_logs.ILogSubscriptionDestination)
+@jsii.implements(_aws_cdk_aws_logs_6c4320fb.ILogSubscriptionDestination)
 class LambdaDestination(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-logs-destinations.LambdaDestination",
@@ -194,7 +185,7 @@ class LambdaDestination(
 
     def __init__(
         self,
-        fn: aws_cdk.aws_lambda.IFunction,
+        fn: _aws_cdk_aws_lambda_5443dbc3.IFunction,
         *,
         add_permissions: typing.Optional[builtins.bool] = None,
     ) -> None:
@@ -204,13 +195,7 @@ class LambdaDestination(
         :param add_permissions: Whether or not to add Lambda Permissions. Default: true
         '''
         if __debug__:
-            def stub(
-                fn: aws_cdk.aws_lambda.IFunction,
-                *,
-                add_permissions: typing.Optional[builtins.bool] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__d6e9710da2f352eb7ad07824e7b66d1ebed3cc7d064cf10765da4b89bba002b6)
             check_type(argname="argument fn", value=fn, expected_type=type_hints["fn"])
         options = LambdaDestinationOptions(add_permissions=add_permissions)
 
@@ -219,9 +204,9 @@ class LambdaDestination(
     @jsii.member(jsii_name="bind")
     def bind(
         self,
-        scope: aws_cdk.core.Construct,
-        log_group: aws_cdk.aws_logs.ILogGroup,
-    ) -> aws_cdk.aws_logs.LogSubscriptionDestinationConfig:
+        scope: _aws_cdk_core_f4b25747.Construct,
+        log_group: _aws_cdk_aws_logs_6c4320fb.ILogGroup,
+    ) -> _aws_cdk_aws_logs_6c4320fb.LogSubscriptionDestinationConfig:
         '''Return the properties required to send subscription events to this destination.
 
         If necessary, the destination can use the properties of the SubscriptionFilter
@@ -235,15 +220,10 @@ class LambdaDestination(
         :param log_group: -
         '''
         if __debug__:
-            def stub(
-                scope: aws_cdk.core.Construct,
-                log_group: aws_cdk.aws_logs.ILogGroup,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__4ba2efb1140cf6ba20e3f95e28c51159452ea50ab55b1c99c71c674565a2eeaf)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument log_group", value=log_group, expected_type=type_hints["log_group"])
-        return typing.cast(aws_cdk.aws_logs.LogSubscriptionDestinationConfig, jsii.invoke(self, "bind", [scope, log_group]))
+        return typing.cast(_aws_cdk_aws_logs_6c4320fb.LogSubscriptionDestinationConfig, jsii.invoke(self, "bind", [scope, log_group]))
 
 
 @jsii.data_type(
@@ -274,11 +254,9 @@ class LambdaDestinationOptions:
             )
         '''
         if __debug__:
-            def stub(*, add_permissions: typing.Optional[builtins.bool] = None) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__7123c240d0039fa7cbf58a80b76d5efafce8333f0c03a85148eeaf9ccfce30fc)
             check_type(argname="argument add_permissions", value=add_permissions, expected_type=type_hints["add_permissions"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if add_permissions is not None:
             self._values["add_permissions"] = add_permissions
 
@@ -311,3 +289,47 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__4c1fc1e74b65f4712e89c4da0bc617dea03f0d103b6d5ca34d70a034ee992f15(
+    stream: _aws_cdk_aws_kinesis_0674c215.IStream,
+    *,
+    role: typing.Optional[_aws_cdk_aws_iam_940a1ce0.IRole] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__c036c7cb7cf460a876c094390792817933a81fdf009c1e122eac612b990bc23d(
+    scope: _aws_cdk_core_f4b25747.Construct,
+    _source_log_group: _aws_cdk_aws_logs_6c4320fb.ILogGroup,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__70edd2e2361dad9ce17031d23675b0d1700425bd13f9b6b2318cf360863cc596(
+    *,
+    role: typing.Optional[_aws_cdk_aws_iam_940a1ce0.IRole] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__d6e9710da2f352eb7ad07824e7b66d1ebed3cc7d064cf10765da4b89bba002b6(
+    fn: _aws_cdk_aws_lambda_5443dbc3.IFunction,
+    *,
+    add_permissions: typing.Optional[builtins.bool] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__4ba2efb1140cf6ba20e3f95e28c51159452ea50ab55b1c99c71c674565a2eeaf(
+    scope: _aws_cdk_core_f4b25747.Construct,
+    log_group: _aws_cdk_aws_logs_6c4320fb.ILogGroup,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7123c240d0039fa7cbf58a80b76d5efafce8333f0c03a85148eeaf9ccfce30fc(
+    *,
+    add_permissions: typing.Optional[builtins.bool] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
